summaryrefslogtreecommitdiff
path: root/src/modules/m_allowinvite.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/modules/m_allowinvite.cpp')
-rw-r--r--src/modules/m_allowinvite.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/modules/m_allowinvite.cpp b/src/modules/m_allowinvite.cpp
index 2bfa88823..08a5f542a 100644
--- a/src/modules/m_allowinvite.cpp
+++ b/src/modules/m_allowinvite.cpp
@@ -19,7 +19,7 @@
#include "inspircd.h"
/* $ModDesc: Provides support for channel mode +A, allowing /invite freely on a channel (and extban A to allow specific users it) */
class AllowInvite : public SimpleChannelModeHandler
{
@@ -75,7 +75,7 @@ class ModuleAllowInvite : public Module
virtual Version GetVersion()
{
- return Version("Provides support for channel mode +A, allowing /invite freely on a channel (and extban A to allow specific users it)",VF_VENDOR);
+ return Version("Provides support for channel mode +A, allowing /invite freely on a channel and extban A to deny specific users it",VF_VENDOR);
}
};
@@ -19,7 +19,7 @@
#include "inspircd.h"
-/* $ModDesc: Provides support for channel mode +A, allowing /invite freely on a channel (and extban A to allow specific users it) */
+/* $ModDesc: Provides support for channel mode +A, allowing /invite freely on a channel and extban A to deny specific users it */
class AllowInvite : public SimpleChannelModeHandler
{